@@ -5,9 +5,10 @@ from typing import Union,List,Dict,Tuple
 from cryoloBM import constants,helper,MySketch,helper_filament
 from cryolo import utils    # for type hinting purpose
 from os import path
-from math import sqrt as math_sqrt
+from math import isnan,sqrt as math_sqrt
 from copy import deepcopy
 
+
 class Box_dictionary:
     def __init__(self, type_case: constants.Type_case, onlyfiles: List[str], tot_slices: int = None  ) -> None:
         """
@@ -179,13 +180,14 @@ class Box_dictionary:
                         sketch.resize(sketch.get_est_size(circle=False) if use_estimated_size else new_boxsize)	        # resize the sketch of particle_dictionary
                         self.create_3D(sketch,f,n, is_start_end_filament = False)
 
-    def _resize_all_filament(self, new_boxsize:int, f:str, n:int=None)->List[MySketch.MySketch]:
+    def _resize_all_current_filament(self, new_boxsize:int, f:str, n:int=None,is_saving_on_file=False)->List[MySketch.MySketch]:
         """
         Resize and return the sketches in the present in the given file 'f'
         ONLY 2D cases
         :param new_boxsize: the new boxsize value
         :param f: filename
         :param n: number of slice. The untraced cbox are 2D but on Tomo
+        :param is_saving_on_file: True if we are saving on file
         :return: list of resized Mysketch obj present in the given file 'f'
         """
         starting_vis = self.has_same_visualization(visualization=constants.Visualization_cb.RECT_FILAMENT_START_END.value,f=f,n=n)
@@ -218,10 +220,12 @@ class Box_dictionary:
         self.fil_start_end_vis = True
         self._set_sketches(list_sketches=fil_start_end, f=f, n=n)
         self.fil_start_end_vis = starting_vis
+        if is_saving_on_file:
+            return fil_segmented
         return fil_start_end if starting_vis else fil_segmented
 
 
-    def resized_and_get_sketches(self, new_boxsize:int, f:str, n:int=None, use_estimated_size:bool = False)->List[MySketch.MySketch]:
+    def resized_and_get_sketches(self, new_boxsize:int, f:str, n:int=None, use_estimated_size:bool = False,is_saving_on_file=False)->List[MySketch.MySketch]:
         """
         Resize and return the sketches in the present in the given file 'f'
         ONLY 2D cases
@@ -229,10 +233,11 @@ class Box_dictionary:
         :param f: filename
         :param n: number of slice. The untraced cbox are 2D but on Tomo
         :param use_estimated_size: if True uses the estimated value present in the box (Mysketch obj)
+        :param is_saving_on_file: True if we are saving on file
         :return: list of resized Mysketch obj present in the given file 'f'
         """
         if self.has_filament:
-            boxes=self._resize_all_filament(new_boxsize=new_boxsize, f=f, n=n)
+            boxes=self._resize_all_current_filament(new_boxsize=new_boxsize, f=f, n=n,is_saving_on_file=is_saving_on_file)
         else:
             boxes = self.get_sketches(f=f,n=n, is_3D=self.is_3D,  is_tracing = False)
             for box in boxes:
@@ -258,6 +263,22 @@ class Box_dictionary:
         else:
             dict_2D[f][n] = list_sketches
 
+    def change_box_size_all(self, new_box_size:int,is_saving_on_file:bool=True)->None:
+        """
+        change the distance between the sketches in all the dict, it is used before saving on file
+        :param new_box_size: new boxsize of a sketch (of course it is referred to the segmented mode)
+        :param is_saving_on_file: True if we are saving on file
+        """
+        starting_vis = self.fil_start_end_vis
+        self.fil_start_end_vis = False
+        for k1 in self.particle_dictionary.keys():
+            if self.type_case == constants.Type_case.SPA.value:
+                self.particle_dictionary[k1] = self.resized_and_get_sketches(new_boxsize=new_box_size, f=k1, n=None, use_estimated_size=False,is_saving_on_file=is_saving_on_file)
+            else:
+                for k2 in self.particle_dictionary[k1].keys():
+                    self.particle_dictionary[k1][k2] = self.resized_and_get_sketches(new_boxsize=new_box_size, f=k1, n=k2,  use_estimated_size=False,is_saving_on_file=is_saving_on_file)
+        self.fil_start_end_vis = starting_vis
+
     def change_box_distance_all(self, new_box_distance:int)->None:
         """
         change the distance between the sketches in all the dict, it is used before saving on file
@@ -326,7 +347,7 @@ class Box_dictionary:
 
         for box in fil_segmented:
             if box.id in listed_sketches:
-                z = int(box.z) if box.z is not None else box.z  # otherwise if z is a float it crashes in utils.resample_filament
+                z = int(box.z) if box.z is not None and not isnan(box.z) else box.z  # otherwise if z is a float it crashes in utils.resample_filament
                 listed_sketches[box.id].append(box.get_as_BBox(confidence=box.get_confidence(), z=z))
 
         # Create the new list of boxes
