@@ -253,6 +253,7 @@ def import_SPA(controller:boxmanager_controller, box_dir:str, keep:bool)->bool:
     is_star_startend = False
 
     controller.view.is_updating_params = True
+    valid_import = False
     for file_index, f in enumerate(onlyfiles):
         pd.setValue(int((file_index + 1) * 100 / len(onlyfiles)))
         controller.view.run_in_same_thread()
@@ -302,9 +303,9 @@ def import_SPA(controller:boxmanager_controller, box_dir:str, keep:bool)->bool:
 
         updated_entries.append(dict_entry_name)
 
-    # in case we try to load particles and keep the filaments we have an invalid import. We do not change the boxsize.
-    # Pay attention: if you try to do that the boxsize will be equal to the height of the last picked/loaded filament
-    valid_import = bool(len(boxes))
+        # in case we try to load particles and keep the filaments we have an invalid import. We do not change the boxsize.
+        # Pay attention: if you try to do that the boxsize will be equal to the height of the last picked/loaded filament
+        valid_import = bool(len(boxes)) or valid_import
 
     # i have to set th boxesize to the GUI, in particle is done into _load_data
     if valid_import and controller.model.has_filament and controller.model.rectangles:
@@ -531,11 +532,8 @@ def import_data(controller:boxmanager_controller)->None:
     # update counters
     controller.view.update_tree_boxsizes( update_current=False,all_tomos=True)
     controller.view.update_all_global_counters()
-
     # in case of cbox filament some options are not available
     if controller.model.has_filament:
         controller.view.blur_estimated_size()
-        if not controller.model.is_cbox_untraced:
-            box_dist = controller.model.box_dictionary.set_box_distance_dict_after_import()
-            controller.model.box_distance_filament = box_dist
-            controller.view.line_setText(line=controller.view.box_distance_filament_line, value=str(box_dist))
\ No newline at end of file
+        controller.model.box_distance_filament = controller.model.box_dictionary.set_box_distance_dict_after_import()
+        controller.view.line_setText(line=controller.view.box_distance_filament_line, value=str(controller.model.box_distance_filament))
\ No newline at end of file
